@@ -7,11 +7,11 @@ other_names = 'https://api.github.com/repos/ryayoung/datasets/git/trees/main?rec
 def load_data(name, **kwargs):
     # In the future start using different branch to store data, so I won't mess it up
     url = f'https://raw.githubusercontent.com/ryayoung/datasets/main/{name}.csv'
-    index_col = kwargs.get("index_col", None)
 
     try:
-        df = pd.read_csv(url, index_col=index_col, **kwargs)
+        df = pd.read_csv(url, **kwargs)
     except Exception as e:
+        print(e)
         r = requests.get(other_names)
         res = r.json()['tree']
         names = [f"'{f['path'].removesuffix('.csv')}'" for f in res]
